#ifndef WPIPE_MATLAB_FCS
#define WPIPE_MATLAB_FCS

#include <string>
#include <cmath>
#include "wtypes.hh"

namespace wpipe {

  /** local time string
   */
  std::string datestr(unsigned long t, int len);

  /**  Remove leading and trailing blanks from a string.
   */
  std::string deblank(const std::string& str);
  
  /**  Throw a runtime error exception.
   */
  void error(const std::string& err);

  /**  parse a vector of doubles
   */
  dble_vect eval(const std::string& str);

  /**  parse a vector of doubles
   */
  str_vect eval_str(const std::string& str);

  /**  Test file existance
   */
  bool exist(const std::string& path, const std::string& type);

  /**  Find the greatest common denominator of two integers.
   */
  long gcd(long a, long b);

  /** Find the powerof two that is greater or equal to the specified number.
   */
  long nextpow2(double x);
  
  /** evaluate a polynomial of order N.
   */
  double polyval(const double* coef, int N, double x);

  /**  Round a double to the nearest integer.
   */
  double round(double x);
  
  /** Replace all occurances of a sub-string
   */
  std::string strrep(const std::string& str,
		     const std::string& from,
		     const std::string& to);

  /** convert a string to lower case
   */
  std::string tolower(const std::string& in);

  /** convert a string to upper case
   */
  std::string toupper(const std::string& in);

  /** remove leading and trailing quotes
   */
  std::string unquote(const std::string& in);

  /** Log a warning (status) message of a specified level if hts greater than
   * the specified threshold.
   */
  void wlog(int thresh, int level, const std::string& txt);

} // namespace wpipe

//======================================  Inline functions
inline double
wpipe::round(double x) {
  return std::floor(x + 0.5);
}

#endif // !defined(WPIPE_MATLAB_FCS)
